@@ -1,4 +1,4 @@
-package Pcore::Ext v0.19.7;
+package Pcore::Ext v0.19.8;
 
 use Pcore -dist, -class;
 use Pcore::Util::Scalar qw[is_ref];
@@ -467,7 +467,17 @@ sub _build_app ($self) {
                 onListen: function(api, events) {},
                 onRpc: null
             }),
-            mainView: '$self->{viewport}'
+            mainView: '$self->{viewport}',
+            launch: function() {
+
+                // TODO do we need this???
+                // maybe target more specific android versions.
+                if (Ext.os.is.Android) {
+                    Ext.Viewport.on('painted', function() {
+                        Ext.Viewport.setHeight(window.innerHeight);
+                    });
+                }
+            }
         });
 JS
 
