@@ -20,8 +20,6 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
             }
         },
 
-        pdf => undef,
-
         init => func ['view'], <<"JS",
             if ( !window.pdfjsLib ) {
                 var me = this,
@@ -65,7 +63,7 @@ JS
                     container = document.createElement("div");
 
                 el.innerHTML = '';
-                me.pdf = pdf;
+                view.pdf = pdf;
 
                 container.setAttribute("style", "display:flex;flex-direction:column;justify-content:flex-start;text-align:center;width:100%;");
 
@@ -97,22 +95,22 @@ JS
                         page.render(renderContext);
                     });
                 }
+
+                view.fireEvent('afterPdfLoad', false);
             }).catch( function (error) {
-                view.fireEvent('pdfLoadError', error.message);
-            }).then( function () {
-                view.fireEvent('afterPdfLoad');
+                view.fireEvent('afterPdfLoad', error.message);
             });
 JS
 
         clearPdf => func <<'JS',
             var me = this,
-                view = me.geteView(),
+                view = me.getView(),
                 el = view.innerElement.dom;
 
             // clear current pdf
              el.innerHTML = '';
 
-            me.pdf = null;
+            view.pdf = null;
 JS
     };
 }
@@ -126,6 +124,8 @@ sub EXT_panel : Extend('Ext.Panel') {
             scale => 1,
         },
 
+        pdf => undef,
+
         layout     => 'fit',
         scrollable => \1,
 
